@@ -22,10 +22,10 @@ def bagi_angka(a,b):
 def kurang_angka(a,b):
     return a-b
 
-def add(a):
+def ddprint(a):
     return a
 
-input("DD GUI Library has been installed.")
+#input("DD GUI Library has been installed.")
 
 """
 # First Method
@@ -79,3 +79,4 @@ if __name__ == "__main__":
     form.show()
     a.exec_()
 
+
